@@ -1,10 +1,16 @@
 import datetime
-from typing import Tuple
+from typing import List, Tuple
 
 import whois
 
 from servergrimoire.plugin import Plugin
 
+MARKDOWN = """
+# DNS Check
+
+Check the DNS for the domain
+"""
+
 
 class DNSChecker(Plugin):
     def can_handle(self, directive: str) -> bool:
@@ -52,13 +58,41 @@ class DNSChecker(Plugin):
         self.logger.info(output_strng)
         return output_strng
 
-    def stats(self, directive: str, data: dict) -> Tuple[dict, dict]:
+    def stats(
+        self, directive: str, data: dict
+    ) -> Tuple[List[List], List[List]]:
         stat: dict = {"OK": 0, "KO": 0, "XX": 0}
-        stat[data[directive]["status"]] = 1
-        other = {}
-        if data[directive]["status"] != "OK":
-            try:
-                other = {data[directive]["domain"]: data[directive]["expired"]}
-            except KeyError:
-                other = {}
-        return stat, other
+        other = []
+        for key in data.keys():
+            data_filter = data[key][directive]["status"]
+            stat[data_filter] += 1
+            if data_filter != "OK":
+                try:
+                    other.append(
+                        [data[directive]["domain"], data[directive]["expired"]]
+                    )
+                except KeyError:
+                    pass
+        return [
+            ["OK", stat["OK"]],
+            ["KO", stat["KO"]],
+            ["XX", stat["XX"]],
+        ], other
+
+    def header_stats(self) -> List[str]:
+        return ["Status", "Number"]
+
+    def header_error(self) -> List[str]:
+        return ["URL", "Date"]
+
+    def title_stats(self) -> str:
+        return "DNS Checker Stats"
+
+    def title_error(self) -> str:
+        return "DNS Checker Error"
+
+    def get_markdown(self):
+        """
+        Return info text as Markdown
+        """
+        return MARKDOWN
